@@ -1,6 +1,7 @@
 import collections
 import itertools
 
+import geopandas
 import matplotlib.pyplot as plt
 import more_itertools as mi
 import numpy as np
@@ -11,6 +12,7 @@ import visilibity as vis
 from box import Box
 from lgblkb_tools import logger
 from lgblkb_tools.common.utils import ParallelTasker
+from area import area
 
 from lgblkb_navigation.base_geometry.geom_utils import min_dist
 from lgblkb_navigation.base_geometry.line_utils import TheLine
@@ -723,7 +725,10 @@ class FieldPoly(ThePoly):
 	
 	@logger.trace()
 	def get_subparcel_centers(self,parcel_area,random_state=123,show='',grid_factor=0.1):
-		n_clusters=int(self.p.area/parcel_area)
+		area = self.calculate_area()
+		n_clusters = int( area / parcel_area)
+		if int(area) % int(parcel_area) != 0:
+			n_clusters += 1
 		logger.debug('n_clusters: %s',n_clusters)
 		if n_clusters==0:
 			return self.p.centroid
@@ -735,6 +740,15 @@ class FieldPoly(ThePoly):
 		# logger.debug('cluster_centers:\n%s',cluster_centers)
 		return cluster_centers
 
+	def calculate_area(self):
+		s = geopandas.GeoSeries(self.p)
+		s.crs = f"EPSG:{3857}"
+		s = s.to_crs(epsg=4326)
+		poly = s.geometry[0].exterior
+		coords = list(poly.coords)
+		obj = {'type': 'Polygon', 'coordinates': [coords]}
+		return area(obj)
+
 def get_vis_poly(polygon: FieldPoly):
 	return vis.Polygon([vis.Point(*xy) for xy in polygon.xy[:-1]])
 
